Literature.Plugs.Redirect
(literature v0.5.1)
This plug is responsible for maybe redirecting requests from one path to another inside a publication.
This plug is responsible for maybe redirecting requests from one path to another inside a publication.